dmqclib.prepare.step2\_calc\_stats package
==========================================

.. automodule:: dmqclib.prepare.step2_calc_stats
   :members:
   :show-inheritance:
   :undoc-members:

Submodules
----------

dmqclib.prepare.step2\_calc\_stats.dataset\_a module
----------------------------------------------------

.. automodule:: dmqclib.prepare.step2_calc_stats.dataset_a
   :members:
   :show-inheritance:
   :undoc-members:

dmqclib.prepare.step2\_calc\_stats.summary\_base module
-------------------------------------------------------

.. automodule:: dmqclib.prepare.step2_calc_stats.summary_base
   :members:
   :show-inheritance:
   :undoc-members:
